@@ -4,7 +4,6 @@ import os
 
 from datapkg import DatapkgException
 from datapkg.package import Package
-import datapkg.util
 import datapkg.metadata as M
 
 default_distribution_name = 'datapkg.distribution:IniBasedDistribution'
@@ -78,6 +77,7 @@ class PythonDistribution(DistributionBase):
         # TODO: catch stdout and only print if error
         import commands
         # os.system(cmd)
+        import datapkg.util
         status, output = datapkg.util.getstatusoutput(cmd)
         if status:
             msg = 'Error on attempt to create file structure:\n\n%s' % output
@@ -153,6 +153,7 @@ class PythonDistribution(DistributionBase):
 
     def install_python_package(self, install_dir, pkg_path, tmpdir,
             zip_safe=False):
+        import datapkg.pypkgtools
         pydist = datapkg.pypkgtools.load_distribution(pkg_path)
         installed_path = pydist.install(install_dir, tmpdir, zip_safe)
         self.package.installed_path = installed_path
@@ -185,6 +186,7 @@ class IniBasedDistribution(DistributionBase):
         # Read metadata from config.ini style fileobj
         cfp = ConfigParser.SafeConfigParser()
         cfp.readfp(open(fp))
+        # TODO: utf8 to unicode conversion?
         filemeta = cfp.defaults()
         newmeta = M.MetadataConverter.normalize_metadata(filemeta,
                 keymap=self.keymap)
@@ -201,12 +203,19 @@ class IniBasedDistribution(DistributionBase):
         return self(pkg)
 
     def write(self, path, **kwargs):
-        '''See parent.
+        '''Writes distribution to disk.
+        
+        Metadata written to metadata.txt in ini style (python ConfigParser)
+        with encoding to utf8.
         '''
         if not os.path.exists(path):
             os.makedirs(path)
         meta_path = os.path.join(path, 'metadata.txt')
-        cfp = ConfigParser.SafeConfigParser(self.package.metadata)
+        # use RawConfigParser to avoid magical interpolation feature (and hence
+        # issues with %s in data)
+        cfp = ConfigParser.RawConfigParser()
+        for k,v in self.package.metadata.items():
+            cfp.set('DEFAULT', k, unicode(v).encode('utf8'))
         for filepath, metadata in self.package.manifest.items():
             section = self.manifest_prefix + filepath
             cfp.add_section(section)
@@ -214,7 +223,7 @@ class IniBasedDistribution(DistributionBase):
                 for k,v in metadata.items():
                     # TODO: (?) json dump of v
                     # will be weird for text values json.dumps('x') => '"x"'
-                    cfg.set(section, k, unicode(v))
+                    cfp.set(section, k, unicode(v).encode('utf8'))
         fo = file(meta_path, 'w')
         cfp.write(fo)
         fo.close()
